summaryrefslogtreecommitdiffstats
path: root/kmymoney2/kmymoney2.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit902ba103f2215bcefa22d62b1c9138aa4b88891c (patch)
tree63ef88424b9be33a31e5a8de61343fb8d7633937 /kmymoney2/kmymoney2.h
parent7e51b6d5ddc01fc3bc69f30bc5d3933a7709dbf2 (diff)
downloadkmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.tar.gz
kmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmymoney@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmymoney2/kmymoney2.h')
-rw-r--r--kmymoney2/kmymoney2.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kmymoney2/kmymoney2.h b/kmymoney2/kmymoney2.h
index e310f26..d7f9b15 100644
--- a/kmymoney2/kmymoney2.h
+++ b/kmymoney2/kmymoney2.h
@@ -230,7 +230,7 @@ protected slots:
/**
* Brings up the new category editor and saves the information.
* The dialog will be preset with the name. The tqparent defaults to
* MyMoneyFile::expense()
*
* @param name Name of the account to be created. Could include a full hierarchy
@@ -253,9 +253,9 @@ protected slots:
void slotInvestmentNew(void);
/**
* Create a new investment in a given @p tqparent investment account
*/
- void slotInvestmentNew(MyMoneyAccount& account, const MyMoneyAccount& tqparent);
+ void slotInvestmentNew(MyMoneyAccount& account, const MyMoneyAccount& parent);
/**
* This slot opens the investment editor to edit the currently
@@ -464,7 +464,7 @@ public:
/**
* construtor of KMyMoney2App, calls all init functions to create the application.
*/
- KMyMoney2App(TQWidget* tqparent=0, const char* name=0);
+ KMyMoney2App(TQWidget* parent=0, const char* name=0);
/**
* Destructor
@@ -517,10 +517,10 @@ public:
/**
* This method opens the category editor with the data found in @a account. The
- * tqparent account is preset to @a tqparent but can be modified. If the user
+ * parent account is preset to @a parent but can be modified. If the user
* acknowledges, the category is created.
*/
- void createCategory(MyMoneyAccount& account, const MyMoneyAccount& tqparent);
+ void createCategory(MyMoneyAccount& account, const MyMoneyAccount& parent);
/**
* This method returns the account for a given @a key - @a value pair.
@@ -535,9 +535,9 @@ public:
*/
void setAccountOnlineParameters(const MyMoneyAccount& acc, const MyMoneyKeyValueContainer& kvps);
- KURL selectFile(const TQString& title, const TQString& path, const TQString& tqmask, KFile::Mode mode);
+ KURL selectFile(const TQString& title, const TQString& path, const TQString& mask, KFile::Mode mode);
- const MyMoneyAccount& findAccount(const MyMoneyAccount& acc, const MyMoneyAccount& tqparent) const;
+ const MyMoneyAccount& findAccount(const MyMoneyAccount& acc, const MyMoneyAccount& parent) const;
void createAccount(MyMoneyAccount& newAccount, MyMoneyAccount& parentAccount, MyMoneyAccount& brokerageAccount, MyMoneyMoney openingBal);
@@ -858,7 +858,7 @@ public slots:
* This slot reparents account @p src to be a child of account @p dest
*
* @param src account to be reparented
* @param dest new tqparent
*/
void slotReparentAccount(const MyMoneyAccount& src, const MyMoneyAccount& dest);
@@ -866,7 +866,7 @@ public slots:
* This slot reparents account @p src to be a held at institution @p dest
*
* @param src account to be reparented
* @param dest new tqparent institution
*/
void slotReparentAccount(const MyMoneyAccount& src, const MyMoneyInstitution& dest);
@@ -990,15 +990,15 @@ public slots:
/**
* Brings up the new category editor and saves the information.
* The dialog will be preset with the name and tqparent account.
*
* @param account reference of category to be created. The @p name member
* should be filled by the caller. The object will be filled
* with additional information during the creation process
* esp. the @p id member.
* @param tqparent reference to tqparent account (defaults to none)
*/
- void slotCategoryNew(MyMoneyAccount& account, const MyMoneyAccount& tqparent = MyMoneyAccount());
+ void slotCategoryNew(MyMoneyAccount& account, const MyMoneyAccount& parent = MyMoneyAccount());
/**
* This method updates all KAction items to the current state.
@@ -230,7 +230,7 @@ protected slots:
/**
* Brings up the new category editor and saves the information.
- * The dialog will be preset with the name. The tqparent defaults to
+ * The dialog will be preset with the name. The parent defaults to
* MyMoneyFile::expense()
*
@@ -253,9 +253,9 @@ protected slots:
void slotInvestmentNew(void);
/**
- * Create a new investment in a given @p tqparent investment account
+ * Create a new investment in a given @p parent investment account
*/
@@ -858,7 +858,7 @@ public slots:
*
* @param src account to be reparented
- * @param dest new tqparent
+ * @param dest new parent
*/
void slotReparentAccount(const MyMoneyAccount& src, const MyMoneyAccount& dest);
@@ -866,7 +866,7 @@ public slots:
*
* @param src account to be reparented
- * @param dest new tqparent institution
+ * @param dest new parent institution
*/
void slotReparentAccount(const MyMoneyAccount& src, const MyMoneyInstitution& dest);
@@ -990,15 +990,15 @@ public slots:
/**
* Brings up the new category editor and saves the information.
- * The dialog will be preset with the name and tqparent account.
+ * The dialog will be preset with the name and parent account.
*
* @param account reference of category to be created. The @p name member
@@ -990,15 +990,15 @@ public slots:
* with additional information during the creation process
* esp. the @p id member.
- * @param tqparent reference to tqparent account (defaults to none)
+ * @param parent reference to parent account (defaults to none)
*/